==> spring-boot-starter-warcar-file-2.4.1.2-sources.jar: com/bxm/warcar/file/autoconfigure/HttpFileConfiguration.java <==
package com.bxm.warcar.file.autoconfigure;

import org.springframework.boot.context.properties.ConfigurationProperties;

/**
 * <h3>Shenjue.java基本描述</h3>
 * <p></p>
 *
 * @author hcmony
 * @since V1.0.0, 2019/01/29 09:50
 */
@ConfigurationProperties("warcar.file")
public class HttpFileConfiguration {
	private String endPoint = "oss-cn-shanghai.aliyuncs.com";
	private String accessKeyId = "LTAIKbgmlegMV68t";
	private String accessKeySecret="HdOMFQcjiUoTybjg325Sthx7iUHSSL";
	private String host="https://image.bianxianmao.com/";
	private String bucketName="bxm-image";
	//区分是哪个服务上传的文件
	private String serviceName="defult";
	//文件大小限制，默认4M
	private long limitSize=1024*1024*4;

	public String getEndPoint() {
		return endPoint;
	}

	public void setEndPoint(String endPoint) {
		this.endPoint = endPoint;
	}

	public String getAccessKeyId() {
		return accessKeyId;
	}

	public void setAccessKeyId(String accessKeyId) {
		this.accessKeyId = accessKeyId;
	}

	public String getAccessKeySecret() {
		return accessKeySecret;
	}

	public void setAccessKeySecret(String accessKeySecret) {
		this.accessKeySecret = accessKeySecret;
	}

	public String getHost() {
		return host;
	}

	public void setHost(String host) {
		this.host = host;
	}

	public String getBucketName() {
		return bucketName;
	}

	public void setBucketName(String bucketName) {
		this.bucketName = bucketName;
	}

	public String getServiceName() {
		return serviceName;
	}

	public void setServiceName(String serviceName) {
		this.serviceName = serviceName;
	}

	public long getLimitSize() {
		return limitSize;
	}

	public void setLimitSize(long limitSize) {
		this.limitSize = limitSize;
	}
}

==> spring-boot-starter-warcar-file-2.4.2.4-sources.jar: com/bxm/warcar/file/autoconfigure/HttpFileConfiguration.java <==
package com.bxm.warcar.file.autoconfigure;

import org.springframework.boot.context.properties.ConfigurationProperties;

/**
 * <h3>Shenjue.java基本描述</h3>
 * <p></p>
 *
 * @author hcmony
 * @since V1.0.0, 2019/01/29 09:50
 */
@ConfigurationProperties("warcar.file")
public class HttpFileConfiguration {
	private String endPoint = "oss-cn-shanghai.aliyuncs.com";
	private String accessKeyId = "LTAIKbgmlegMV68t";
	private String accessKeySecret="HdOMFQcjiUoTybjg325Sthx7iUHSSL";
	private String host="https://image.bianxianmao.com/";
	private String bucketName="bxm-image";
	//区分是哪个服务上传的文件
	private String serviceName="defult";
	//文件大小限制，默认4M
	private long limitSize=1024*1024*4;

    /**
     * 亚马逊服务区域
     * @see com.amazonaws.regions.Regions
     */
    private String amazonRegion = "us-east-1";


    public String getAmazonRegion() {
        return amazonRegion;
    }

    public void setAmazonRegion(String amazonRegion) {
        this.amazonRegion = amazonRegion;
    }

    public String getEndPoint() {
		return endPoint;
	}

	public void setEndPoint(String endPoint) {
		this.endPoint = endPoint;
	}

	public String getAccessKeyId() {
		return accessKeyId;
	}

	public void setAccessKeyId(String accessKeyId) {
		this.accessKeyId = accessKeyId;
	}

	public String getAccessKeySecret() {
		return accessKeySecret;
	}

	public void setAccessKeySecret(String accessKeySecret) {
		this.accessKeySecret = accessKeySecret;
	}

	public String getHost() {
		return host;
	}

	public void setHost(String host) {
		this.host = host;
	}

	public String getBucketName() {
		return bucketName;
	}

	public void setBucketName(String bucketName) {
		this.bucketName = bucketName;
	}

	public String getServiceName() {
		return serviceName;
	}

	public void setServiceName(String serviceName) {
		this.serviceName = serviceName;
	}

	public long getLimitSize() {
		return limitSize;
	}

	public void setLimitSize(long limitSize) {
		this.limitSize = limitSize;
	}
}
